summaryrefslogtreecommitdiffstatshomepage
path: root/src/lib/netlist/nltypes.h
diff options
context:
space:
mode:
author couriersud <couriersud@gmx.org>2019-10-31 18:39:09 +0100
committer couriersud <couriersud@gmx.org>2019-10-31 18:39:09 +0100
commit6c075e602cf83b379b8fa2c981694134b679a538 (patch)
treef483a7149300768974de6b33036abd22be86734b /src/lib/netlist/nltypes.h
parentcae02668fa8ef2c31b1d66ac4b7784b84bb734ac (diff)
netlist: maintenance and simplifcation. (nw)
- solver: align matrix population along the various solvers - solver: delete dead code - renamed nl_double to nl_fptype and use nl_fptype where previously double has been used. - renamed param_double_t to param_fp_t
Diffstat (limited to 'src/lib/netlist/nltypes.h')
-rw-r--r--src/lib/netlist/nltypes.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/lib/netlist/nltypes.h b/src/lib/netlist/nltypes.h
index 75470ca2ebf..fe51be8c17d 100644
--- a/src/lib/netlist/nltypes.h
+++ b/src/lib/netlist/nltypes.h
@@ -27,12 +27,12 @@
namespace netlist
{
/*! @brief plib::constants struct specialized for nl_double
*
* This may be any of bool, uint8_t, uint16_t, uin32_t and uint64_t.
* The choice has little to no impact on performance.
*/
- using constants = plib::constants<nl_double>;
+ using constants = plib::constants<nl_fptype>;
/*! @brief netlist_sig_t is the type used for logic signals.
*
@@ -27,12 +27,12 @@
namespace netlist
{
- /*! @brief plib::constants struct specialized for nl_double
+ /*! @brief plib::constants struct specialized for nl_fptype
*
* This may be any of bool, uint8_t, uint16_t, uin32_t and uint64_t.